@@ -132,13 +132,13 @@ void FlashCardModeWidget::setSolutionSound(const QUrl &soundUrl)
 
 void FlashCardModeWidget::setSolutionPronunciation(const QString &pronunciationText)
 {
-    m_ui->solutionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->solutionPronunciationLabel->setText(QLatin1Char('[') + pronunciationText + QLatin1Char(']'));
     m_ui->solutionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 void FlashCardModeWidget::setQuestionPronunciation(const QString &pronunciationText)
 {
-    m_ui->questionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->questionPronunciationLabel->setText(QLatin1Char('[') + pronunciationText + QLatin1Char(']'));
     m_ui->questionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
